;=================================================
; Testcard demo for introduction to basic
; By Andew Colin (1982)
; 
; The originale song use a Basic/machine
; code for generating music
; This is a machine code port 
; The code can generate a PRG or SID file.
; Note: the original code don't use the IRQ 
; routine. However, the engine used is a 
; minor version of one used in  "Return of Sheba",
; so it is taken to be used here
;=================================================

.ifdef sid
 .byte "PSID"
 .word $0200         ; version 2
 .word $7C00         ; data offset
 .word $0000         ; load address in cbm format
 .byte >initMusic
 .byte <initMusic 
 .byte >playMusic
 .byte <playMusic 
 .word $0400         ; 1 song
 .word $0100         ; default song
 .word $FFFF
 .word $FFFF
 .byte "Testcard",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
 .byte "Andrew Colin",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
 .byte "1982 Commodore Inc",0,0,0,0,0,0,0,0,0,0,0,0,0,0
 .word $0000
 .word $0000
 .word $0000
.endif

.org $0801

 ;=================================
 ; PRG start address
 ;=================================
 .byte $01,$08

 ;=================================
 ; BASIC startup program
 ;=================================
 .byte $0b,$08,$e8,$03,$9e,"2061",0,0,0

.org 2061
     jsr initMusic

     sei
     lda #<interr
     sta $0314
     lda #>interr
     sta $0315

     cli

aaa:
 jmp aaa

interr =*
     lda  contr+0
     bne  playMusic
kernal:
     jmp  $ea31

playMusic:  
     ldx #$00
     lda instr+0,x                ; Voice 1: Control registers
     beq nend
     inc instr+5,x
     bne nend
     inc instr+6,x
     bne nend
     lda instr+1,x                ; Voice 1: notes address lo 
     sta $fe
     lda instr+2,x                ; Voice 1: notes address hi
     sta $ff
     ldy #$00
     lda ($fe),y
     asl
     tay
     lda contr+2,y
     sta $d401,x                  ; Voice 1: Frequency control (hi byte)
     lda contr+3,y
     sta $d400,x                  ; Voice 1: Frequency control (lo byte)
     lda instr+3,x                ; Voice 1: notes duration address lo 
     sta $fe
     lda instr+4,x                ; Voice 1: notes duration address hi
     sta $ff
     ldy #$00
     lda ($fe),y
     bne skip
     sta instr+0,x                ; Voice 1: Control registers
     jmp nend
skip:
     tay
loop:     
     lda instr+5,x
     sec
     sbc contr+1
     sta instr+5,x
     lda instr+6,x
     sbc #$00
     sta instr+6,x
     dey
     bne loop
     inc instr+1,x                ; Voice 1: notes address lo 
     bne skip1
     inc instr+2,x                ; Voice 1: notes address hi
skip1:
     inc instr+3,x                ; Voice 1: notes duration address lo 
     bne skip2
     inc instr+4,x                ; Voice 1: notes duration address hi
skip2:
     lda #$00
     sta $d404,x                  ; Voice 1: Control registers
     lda instr+0,x                ; Voice 1: Control registers
     sta $d404,x                  ; Voice 1: Control registers
nend:
     txa
     clc
     adc #$07
     tax
     cmp #$15
     bne skip3
.ifdef sid
     rts
.endif
     jmp kernal
skip3:
     jmp playMusic+2


initMusic =*
                                  ; initialize control registers 
     pha                          ; save tune number

                                  ; erase all sid registers
     ldx  #24
     lda  #0
loop1:
     sta  $D400,x
     dex
     bpl  loop1
     
     pla                          ; tune number
     asl a
     asl a
     asl a
     asl a
     tax
     
     lda songs,x
     sta contr+1                  ; velocity
     inx
     
     lda  songs,x
     sta  $D405                   ; Generator 1: Attack/Decay (voice 1)
     sta  $D40C                   ; Generator 1: Attack/Decay (voice 2)
     sta  $D413                   ; Generator 1: Attack/Decay (voice 3)
     inx
     lda  songs,x
     sta  $D406                   ; Generator 1: Sustain/Release (voice 1)
     sta  $D40D                   ; Generator 1: Sustain/Release (voice 2)
     sta  $D414                   ; Generator 1: Sustain/Release (voice 3)
     inx
     
     lda  #$0F
     sta  $D418                   ; volume
     
     lda  songs,x
     sta  instr+1
     inx
     lda  songs,x
     sta  instr+2
     inx
     
     lda  songs,x
     sta  instr+3
     inx
     lda  songs,x
     sta  instr+4
     inx
     
     lda  songs,x
     sta  instr+8
     inx
     lda  songs,x
     sta  instr+9
     inx
     
     lda  songs,x
     sta  instr+10
     inx
     lda  songs,x
     sta  instr+11
     inx
     
     lda  songs,x
     sta  instr+15
     inx
     lda  songs,x
     sta  instr+16
     inx
     
     lda  songs,x
     sta  instr+17
     inx
     lda  songs,x
     sta  instr+18
     rts
     

                                  ; initialze sid registers

     
songs =*
  .byte $0F                       ; velocity
  .byte $0A                       ; Attack/Decay
  .byte $00                       ; Sustain/Release
  .byte <nGavotte1                ; Voice 1: notes address lo 
  .byte >nGavotte1                ; Voice 1: notes address hi
  .byte <lGavotte1                ; Voice 1: notes duration address lo 
  .byte >lGavotte1                ; Voice 1: notes duration address hi
  .byte <nGavotte2                ; Voice 2: notes address lo 
  .byte >nGavotte2                ; Voice 2: notes address hi
  .byte <lGavotte2                ; Voice 2: notes duration address lo 
  .byte >lGavotte2                ; Voice 2: notes duration address hi
  .byte <nGavotte3                ; Voice 3: notes address lo 
  .byte >nGavotte3                ; Voice 3: notes address hi
  .byte <lGavotte3                ; Voice 3: notes duration address lo 
  .byte >lGavotte3                ; Voice 3: notes duration address hi
  .byte $00
  
  .byte $0E                       ; velocity
  .byte $0C                       ; Attack/Decay
  .byte $00                       ; Sustain/Release
  .byte <nMarines1                ; Voice 1: notes address lo 
  .byte >nMarines1                ; Voice 1: notes address hi
  .byte <lMarines1                ; Voice 1: notes duration address lo 
  .byte >lMarines1                ; Voice 1: notes duration address hi
  .byte <nMarines2                ; Voice 2: notes address lo 
  .byte >nMarines2                ; Voice 2: notes address hi
  .byte <lMarines2                ; Voice 2: notes duration address lo 
  .byte >lMarines2                ; Voice 2: notes duration address hi
  .byte <nNull                    ; Voice 3: notes address lo 
  .byte >nNull                    ; Voice 3: notes address hi
  .byte <nNull                    ; Voice 3: notes duration address lo 
  .byte >nNull                    ; Voice 3: notes duration address hi
  .byte $00
  
  .byte $11                       ; velocity
  .byte $3B                       ; Attack/Decay
  .byte $00                       ; Sustain/Release
  .byte <nAndante1                ; Voice 1: notes address lo 
  .byte >nAndante1                ; Voice 1: notes address hi
  .byte <lAndante1                ; Voice 1: notes duration address lo 
  .byte >lAndante1                ; Voice 1: notes duration address hi
  .byte <nAndante2                ; Voice 2: notes address lo 
  .byte >nAndante2                ; Voice 2: notes address hi
  .byte <lAndante2                ; Voice 2: notes duration address lo 
  .byte >lAndante2                ; Voice 2: notes duration address hi
  .byte <nNull                    ; Voice 3: notes address lo 
  .byte >nNull                    ; Voice 3: notes address hi
  .byte <nNull                    ; Voice 3: notes duration address lo 
  .byte >nNull                    ; Voice 3: notes duration address hi
  .byte $00
  
  .byte $0A                       ; velocity
  .byte $19                       ; Attack/Decay
  .byte $00                       ; Sustain/Release
  .byte <nAllegro1                ; Voice 1: notes address lo 
  .byte >nAllegro1                ; Voice 1: notes address hi
  .byte <lAllegro1                ; Voice 1: notes duration address lo 
  .byte >lAllegro1                ; Voice 1: notes duration address hi
  .byte <nAllegro2                ; Voice 2: notes address lo 
  .byte >nAllegro2                ; Voice 2: notes address hi
  .byte <lAllegro2                ; Voice 2: notes duration address lo 
  .byte >lAllegro2                ; Voice 2: notes duration address hi
  .byte <nNull                    ; Voice 3: notes address lo 
  .byte >nNull                    ; Voice 3: notes address hi
  .byte <nNull                    ; Voice 3: notes duration address lo 
  .byte >nNull                    ; Voice 3: notes duration address hi
  .byte $00
  
  
     
contr =*                          ; control register
  .byte 1;0
  .byte 8                         ; velocity
  .byte 0,0
freq =*
  .byte $02, $d0
  .byte $02, $fb
  .byte $03, $28
  .byte $03, $58
  .byte $00, $00
  .byte $03, $c1
  .byte $03, $fa
  .byte $04, $37
  .byte $04, $77
  .byte $04, $bb
  .byte $05, $03
  .byte $05, $4f
  .byte $05, $a0
  .byte $05, $f6
  .byte $06, $50
  .byte $06, $b0
  .byte $07, $16
  .byte $07, $82
  .byte $07, $f4
  .byte $08, $6e
  .byte $08, $ee
  .byte $09, $76
  .byte $0a, $06
  .byte $0a, $9e
  .byte $0b, $40
  .byte $0b, $eb
  .byte $0c, $a1
  .byte $0d, $61
  .byte $0e, $2d
  .byte $0f, $04
  .byte $0f, $e9
  .byte $10, $db
  .byte $11, $dc
  .byte $12, $ec
  .byte $14, $0c
  .byte $15, $3d
  .byte $16, $80
  .byte $17, $d7
  .byte $19, $41
  .byte $1a, $c2
  .byte $1c, $59
  .byte $1e, $09
  .byte $1f, $d2
  .byte $21, $b6
  .byte $23, $b7
  .byte $25, $d7
  .byte $28, $17
  .byte $2a, $79
  .byte $2d, $00
  .byte $2f, $ad
  .byte $32, $83
  .byte $35, $84
  .byte $38, $b2
  .byte $3c, $11
  .byte $3f, $a4
  .byte $43, $6c
  .byte $47, $6f
  .byte $4b, $ae
  .byte $50, $2e
  .byte $54, $f3

instr=*
  .byte 33                        ; Voice 1: Control registers
  .byte <nGavotte1                ; Voice 1: notes address lo 
  .byte >nGavotte1                ; Voice 1: notes address hi
  .byte <lGavotte1                ; Voice 1: notes duration address lo 
  .byte >lGavotte1                ; Voice 1: notes duration address hi
  .byte 255
  .byte 255
  
  .byte 33                        ; Voice 2: Control registers
  .byte <nGavotte2                ; Voice 2: notes address lo 
  .byte >nGavotte2                ; Voice 2: notes address hi
  .byte <lGavotte2                ; Voice 2: notes duration address lo 
  .byte >lGavotte2                ; Voice 2: notes duration address hi
  .byte 255
  .byte 255
  
  .byte 33                        ; Voice 3: Control registers
  .byte <nGavotte3                ; Voice 3: notes address lo 
  .byte >nGavotte3                ; Voice 3: notes address hi
  .byte <lGavotte3                ; Voice 3: notes duration address lo 
  .byte >lGavotte3                ; Voice 3: notes duration address hi
  .byte 255
  .byte 255
  
nGavotte1 =*                      ; note value for voice 1
  .byte $05, $2c, $2b, $2c, $2e, $2c, $27, $30
  .byte $2e, $30, $31, $30, $2e, $2c, $33, $31
  .byte $30, $2e, $2c, $2e, $2c, $2b, $2c, $2e
  .byte $2c, $27, $30, $2e, $30, $31, $30, $2e
  .byte $2c, $33, $31, $30, $2e, $2c, $2e

  .byte $27, $25, $24, $29, $25, $24, $22, $27
  .byte $24, $22, $20, $25, $24, $22, $20, $1f
  .byte $20, $1f, $20, $22, $20, $1b, $25, $24
  .byte $25, $27, $24, $22, $24, $25, $22, $27
  .byte $20, $1f, $20, $22, $24, $22, $20

  .byte $27, $25, $24, $29, $25, $24, $22, $27
  .byte $24, $22, $20, $25, $24, $22, $20, $1f
  .byte $20, $1f, $20, $22, $20, $1b, $25, $24
  .byte $25, $27, $24, $22, $24, $25, $22, $27
  .byte $20, $1f, $20, $22, $24, $22, $20, $00

lGavotte1 =*                      ; note duration for voice 1
  .byte $08, $01, $01, $01, $01, $02, $02, $01
  .byte $01, $01, $01, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $04, $01, $01, $01, $01
  .byte $02, $02, $01, $01, $01, $01, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $04

  .byte $02, $01, $01, $04, $02, $01, $01, $04
  .byte $02, $01, $01, $02, $02, $02, $02, $04
  .byte $01, $01, $01, $01, $02, $02, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $02, $02
  .byte $01, $01, $01, $01, $02, $02, $04

  .byte $02, $01, $01, $04, $02, $01, $01, $04
  .byte $02, $01, $01, $02, $02, $02, $02, $04
  .byte $01, $01, $01, $01, $02, $02, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $02, $02
  .byte $01, $01, $01, $01, $02, $02, $04, $00

nGavotte2 =*                      ; note value for voice 2
  .byte $05, $05, $27, $27, $29, $2c, $29, $2b
  .byte $2c, $29, $26, $27, $05, $27, $27, $29
  .byte $2c, $29, $2b, $2c, $29, $26, $27

  .byte $20, $24, $22, $20, $22, $05, $22, $20
  .byte $1f, $20, $05, $20, $20, $1d, $1b, $05
  .byte $05, $05, $20, $20, $1f, $20, $22, $20
  .byte $1f, $18

  .byte $20, $24, $22, $20, $22, $05, $22, $20
  .byte $1f, $20, $05, $20, $20, $1d, $1b, $05
  .byte $05, $05, $20, $20, $1f, $20, $22, $20
  .byte $1f, $18, $00

lGavotte2 =*                      ; note duration for voice 2
  .byte $08, $08, $04, $04, $02, $02, $01, $01
  .byte $02, $02, $02, $04, $08, $04, $04, $02
  .byte $02, $01, $01, $02, $02, $02, $04

  .byte $04, $02, $01, $01, $02, $02, $02, $01
  .byte $01, $02, $02, $02, $02, $02, $02, $08
  .byte $08, $06, $02, $01, $01, $01, $01, $02
  .byte $02, $04

  .byte $04, $02, $01, $01, $02, $02, $02, $01
  .byte $01, $02, $02, $02, $02, $02, $02, $08
  .byte $08, $06, $02, $01, $01, $01, $01, $02
  .byte $02, $04, $00

nGavotte3 =*                      ; note value for voice 3
  .byte $05, $14, $18, $1b, $20, $1f, $20, $22
  .byte $20, $1f, $1d, $24, $22, $20, $19, $1d
  .byte $1b, $19, $18, $16, $14, $18, $1b, $20
  .byte $1f, $20, $22, $20, $1f, $1d, $24, $22
  .byte $20, $19, $1d, $1b

  .byte $18, $14, $11, $16, $13, $11, $0f, $14
  .byte $18, $11, $14, $16, $18, $1b, $19, $18
  .byte $16, $18, $14, $16, $1f, $20, $14, $1b
  .byte $19, $18, $1d, $19, $1b, $0f, $14

  .byte $18, $14, $11, $16, $13, $11, $0f, $14
  .byte $18, $11, $14, $16, $18, $1b, $19, $18
  .byte $16, $18, $14, $16, $1f, $20, $14, $1b
  .byte $19, $18, $1d, $19, $1b, $0f, $14, $00
  
lGavotte3 =*                      ; note duration for voice 3
  .byte $08, $04, $02, $02, $01, $01, $01, $01
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $01, $01, $01, $01, $04, $02, $02, $01
  .byte $01, $01, $01, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $04

  .byte $04, $02, $02, $04, $02, $01, $01, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $01
  .byte $01, $02, $02, $02, $02, $02, $04

  .byte $04, $02, $02, $04, $02, $01, $01, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $01
  .byte $01, $02, $02, $02, $02, $02, $04, $00

nMarines1 =*
  .byte $05, $1e, $22, $25, $25, $25, $25, $25
  .byte $2a, $25, $22, $23, $25, $25, $23, $20
  .byte $1e, $1e, $22, $25, $25, $25, $25, $25
  .byte $2a, $25, $22, $23, $25, $25, $23, $20
  .byte $1e, $2a, $29, $27, $23, $27, $23, $25
  .byte $27, $25, $2a, $29, $27, $23, $27, $2a
  .byte $25, $1e, $22, $25, $25, $25, $25, $25
  .byte $2a, $25, $22, $23, $25, $25, $23, $20
  .byte $1e, $00 

lMarines1 =*
  .byte $08, $01, $01, $02, $02, $02, $02, $03
  .byte $01, $02, $01, $01, $02, $02, $02, $02
  .byte $06, $01, $01, $02, $02, $02, $02, $03
  .byte $01, $02, $01, $01, $02, $02, $02, $02
  .byte $06, $01, $01, $02, $02, $02, $02, $03
  .byte $01, $02, $01, $01, $02, $02, $02, $02
  .byte $06, $01, $01, $02, $02, $02, $02, $03
  .byte $01, $02, $01, $01, $02, $02, $02, $02
  .byte $07, $00

nMarines2 =*
  .byte $05, $12, $12, $16, $16, $05, $16, $05
  .byte $16, $05, $16, $05, $16, $16, $16, $16
  .byte $05, $11, $11, $05, $11, $05, $11, $05
  .byte $11, $12, $16, $16, $16, $16, $05, $16
  .byte $16, $05, $16, $05, $16, $05, $16, $05
  .byte $16, $16, $16, $16, $05, $11, $11, $05
  .byte $11, $05, $11, $05, $11, $12, $16, $16
  .byte $16, $16, $05, $05, $17, $05, $12, $05
  .byte $17, $05, $12, $05, $16, $16, $16, $16
  .byte $05, $05, $17, $05, $12, $05, $17, $05
  .byte $12, $05, $16, $16, $16, $16, $05, $16
  .byte $16, $05, $16, $05, $16, $05, $16, $05
  .byte $16, $16, $16, $16, $05, $11, $11, $05
  .byte $11, $05, $11, $05, $11, $12, $16, $16
  .byte $16, $16, $00

lMarines2 =*
  .byte $08, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $02
  .byte $02, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $02, $02, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $02, $02, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $02, $02, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $02
  .byte $02, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $02, $02, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $02, $02, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $03, $00

nAndante1 =*
  .byte $05, $2a, $2c, $2a, $2c, $2e, $2a, $25
  .byte $25, $25, $2c, $2e, $2c, $2e, $2f, $2c
  .byte $25, $25, $25, $31, $29, $2a, $2c, $29
  .byte $2a, $33, $30, $2c, $2a, $29, $31, $2e
  .byte $33, $31, $30, $30, $31, $05 
 
  .byte $05, $2a, $2c, $2a, $2c, $2e, $2a, $25
  .byte $25, $25, $2c, $2e, $2c, $2e, $2f, $2c
  .byte $25, $25, $25, $31, $29, $2a, $2c, $29
  .byte $2a, $33, $30, $2c, $2a, $29, $31, $2e
  .byte $33, $31, $30, $30, $31, $05 
 
  .byte $31, $2e, $2f, $31, $33, $2f, $2c, $2e
  .byte $2f, $31, $2f, $2e, $2c, $2e, $2a, $2f
  .byte $2e, $2c, $05, $2f, $2e, $2c, $2a, $29
  .byte $31, $2f, $2e, $2c, $2a, $27, $33, $2f
  .byte $2c, $2a, $29, $29, $2a, $05 
 
  .byte $31, $2e, $2f, $31, $33, $2f, $2c, $2e
  .byte $2f, $31, $2f, $2e, $2c, $2e, $2a, $2f
  .byte $2e, $2c, $05, $2f, $2e, $2c, $2a, $29
  .byte $31, $2f, $2e, $2c, $2a, $27, $33, $2f
  .byte $2c, $2a, $29, $29, $2a, $05, $00

lAndante1 =*
  .byte $04, $04, $01, $01, $01, $01, $02, $02
  .byte $02, $02, $04, $01, $01, $01, $01, $02
  .byte $02, $02, $02, $04, $01, $01, $01, $01
  .byte $04, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $02, $02, $04, $02, $02 
  
  .byte $04, $04, $01, $01, $01, $01, $02, $02
  .byte $02, $02, $04, $01, $01, $01, $01, $02
  .byte $02, $02, $02, $04, $01, $01, $01, $01
  .byte $04, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $02, $02, $04, $02, $02 
  
  .byte $04, $01, $01, $01, $01, $04, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $02, $02
  .byte $04, $02, $02, $04, $01, $01, $01, $01
  .byte $04, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $02, $02, $04, $02, $02 
  
  .byte $04, $01, $01, $01, $01, $04, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $02, $02
  .byte $04, $02, $02, $04, $01, $01, $01, $01
  .byte $04, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $02, $02, $04, $02, $02, $00

nAndante2 =*
  .byte $05, $22, $25, $22, $1e, $22, $25, $22
  .byte $25, $22, $1e, $25, $2a, $29, $2a, $2c
  .byte $29, $25, $29, $2c, $29, $2c, $29, $25
  .byte $22, $05, $25, $27, $24, $25, $2a, $2c
  .byte $2c, $2c, $25, $05
  
  .byte $05, $22, $25, $22, $1e, $22, $25, $22
  .byte $25, $22, $1e, $25, $2a, $29, $2a, $2c
  .byte $29, $25, $29, $2c, $29, $2c, $29, $25
  .byte $22, $05, $25, $27, $24, $25, $2a, $2c
  .byte $2c, $2c, $25, $05
  
  .byte $05, $2e, $2b, $27, $05, $2c, $29, $25
  .byte $2a, $29, $27, $2c, $2a, $1e, $22, $1e
  .byte $25, $05, $2c, $29, $25, $05, $22, $2a
  .byte $27, $05, $24, $25, $05, $05, $1e, $05
  
  .byte $05, $2e, $2b, $27, $05, $2c, $29, $25
  .byte $2a, $29, $27, $2c, $2a, $1e, $22, $1e
  .byte $25, $05, $2c, $29, $25, $05, $22, $2a
  .byte $27, $05, $24, $25, $05, $05, $1e, $05
  .byte $00

lAndante2 =*
  .byte $04, $04, $04, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $04, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $02, $02, $04, $04, $04, $02, $02, $02
  .byte $02, $04, $02, $02 
 
  .byte $04, $04, $04, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $04, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $02, $02, $04, $04, $04, $02, $02, $02
  .byte $02, $04, $02, $02

  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $01, $01, $01, $01
  .byte $02, $04, $02, $02, $02, $02, $02, $02
  .byte $02, $03, $01, $02, $02, $04, $02, $02

  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $01, $01, $01, $01
  .byte $02, $04, $02, $02, $02, $02, $02, $02
  .byte $02, $03, $01, $02, $02, $04, $02, $02
  .byte $00

nAllegro1 =*
  .byte $05, $2e, $31, $2f, $2e, $2c, $2a, $05
  .byte $2a, $2c, $2c, $2c, $2c, $2e, $2a, $05
  .byte $2a, $2c, $2c, $2c, $2c, $2e, $2a, $2c
  .byte $2e, $2f, $31, $33, $35, $36, $33, $2e
  .byte $30, $31, $05, $31, $33, $35, $36, $33
  .byte $30, $31, $33, $30, $31, $33, $35, $36
  .byte $31, $35, $33, $31, $33, $35, $36, $33
  .byte $30, $31, $33, $30, $31, $05
  
  .byte $05, $2e, $31, $2f, $2e, $2c, $2a, $05
  .byte $2a, $2c, $2c, $2c, $2c, $2e, $2a, $05
  .byte $2a, $2c, $2c, $2c, $2c, $2e, $2a, $2c
  .byte $2e, $2f, $31, $33, $35, $36, $33, $2e
  .byte $30, $31, $05, $31, $33, $35, $36, $33
  .byte $30, $31, $33, $30, $31, $33, $35, $36
  .byte $31, $35, $33, $31, $33, $35, $36, $33
  .byte $30, $31, $33, $30, $31, $05 
  
  .byte $25, $31, $2e, $33, $31, $2f, $2c, $31
  .byte $2f, $2e, $2a, $2f, $2e, $2c, $2a, $31
  .byte $05, $2e, $31, $2f, $2e, $2c, $2a, $2c
  .byte $2e, $2f, $31, $33, $35, $36, $35, $2a
  .byte $2c, $2e, $2f, $31, $2e, $2c, $2a, $35
  .byte $36, $05, $31, $05, $2f, $05, $2c, $05
  .byte $2a, $05, $25, $2a, $2a, $2a, $25, $2e
  .byte $2e, $2e, $2a, $31, $2c, $2e, $2a, $05
  
  .byte $25, $31, $2e, $33, $31, $2f, $2c, $31
  .byte $2f, $2e, $2a, $2f, $2e, $2c, $2a, $31
  .byte $05, $2e, $31, $2f, $2e, $2c, $2a, $2c
  .byte $2e, $2f, $31, $33, $35, $36, $35, $2a
  .byte $2c, $2e, $2f, $31, $2e, $2c, $2a, $35
  .byte $36, $05, $31, $05, $2f, $05, $2c, $05
  .byte $2a, $05, $25, $2a, $2a, $2a, $25, $2e
  .byte $2e, $2e, $2a, $31, $2c, $2e, $2a, $05
  .byte $00

lAllegro1 =*
  .byte $08, $02, $02, $02, $02, $02, $04, $02
  .byte $02, $02, $02, $02, $01, $01, $04, $02
  .byte $02, $02, $02, $02, $01, $01, $02, $01
  .byte $01, $01, $01, $01, $01, $02, $02, $02
  .byte $02, $04, $02, $02, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $04, $02
 
  .byte $08, $02, $02, $02, $02, $02, $04, $02
  .byte $02, $02, $02, $02, $01, $01, $04, $02
  .byte $02, $02, $02, $02, $01, $01, $02, $01
  .byte $01, $01, $01, $01, $01, $02, $02, $02
  .byte $02, $04, $02, $02, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $01
  .byte $01, $01, $01, $01, $04, $02
  
  .byte $02, $06, $02, $06, $02, $06, $02, $06
  .byte $02, $06, $04, $04, $04, $04, $02, $04
  .byte $02, $02, $02, $02, $02, $02, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $08, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $08
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $04, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $04, $03, $01, $04, $02
  
  .byte $02, $06, $02, $06, $02, $06, $02, $06
  .byte $02, $06, $04, $04, $04, $04, $02, $04 
  .byte $02, $02, $02, $02, $02, $02, $01, $01
  .byte $01, $01, $01, $01, $01, $01, $08, $01
  .byte $01, $01, $01, $01, $01, $01, $01, $08
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $04, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $04, $03, $01, $04, $02
  .byte $00

nAllegro2 =*
  .byte $05, $2a, $2e, $2c, $2a, $25, $22, $05
  .byte $22, $25, $25, $25, $25, $22, $05, $22
  .byte $25, $25, $25, $25, $22, $05, $2a, $29
  .byte $2c, $29, $2c, $2a, $2c, $2a, $2c, $29 
  .byte $2c, $29, $2c, $2a, $2c, $2a, $2c, $29
  .byte $05 
  
  .byte $05, $2a, $2e, $2c, $2a, $25, $22, $05
  .byte $22, $25, $25, $25, $25, $22, $05, $22 
  .byte $25, $25, $25, $25, $22, $05, $2a, $29
  .byte $2c, $29, $2c, $2a, $2c, $2a, $2c, $29
  .byte $2c, $29, $2c, $2a, $2c, $2a, $2c, $29
  .byte $05 
  
  .byte $05, $1e, $2a, $27, $2c, $2a, $29, $25
  .byte $2a, $29, $28, $27, $25, $23, $24, $25
  .byte $05, $2a, $2e, $2c, $2a, $25, $22, $05
  .byte $2e, $2f, $2c, $31, $2f, $2e, $05, $2e
  .byte $2f, $2c, $31, $2f, $2e, $05, $2e, $05
  .byte $2c, $05, $25, $05, $22, $05, $19, $1e
  .byte $1e, $1e, $19, $22, $22, $22, $1e, $25
  .byte $19, $1e, $05 
  
  .byte $05, $1e, $2a, $27, $2c, $2a, $29, $25
  .byte $2a, $29, $28, $27, $25, $23, $24, $25 
  .byte $05, $2a, $2e, $2c, $2a, $25, $22, $05
  .byte $2e, $2f, $2c, $31, $2f, $2e, $05, $2e
  .byte $2f, $2c, $31, $2f, $2e, $05, $2e, $05
  .byte $2c, $05, $25, $05, $22, $05, $19, $1e
  .byte $1e, $1e, $19, $22, $22, $22, $1e, $25
  .byte $19, $1e, $05, $00
  
lAllegro2 =*
  .byte $08, $02, $02, $02, $02, $02, $04, $02
  .byte $02, $02, $02, $02, $02, $04, $02, $02
  .byte $02, $02, $02, $02, $04, $04, $08, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $04
  .byte $02 
  
  .byte $08, $02, $02, $02, $02, $02, $04, $02
  .byte $02, $02, $02, $02, $02, $04, $02, $02 
  .byte $02, $02, $02, $02, $04, $04, $08, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $04
  .byte $02 
  
  .byte $04, $02, $06, $02, $06, $02, $06, $02
  .byte $06, $02, $04, $04, $04, $04, $04, $04
  .byte $02, $02, $02, $02, $02, $02, $04, $02
  .byte $02, $02, $02, $02, $02, $04, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $04, $02, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $04, $04, $04 
 
  .byte $04, $02, $06, $02, $06, $02, $06, $02
  .byte $06, $02, $04, $04, $04, $04, $04, $04
  .byte $02, $02, $02, $02, $02, $02, $04, $02
  .byte $02, $02, $02, $02, $02, $04, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $02, $02, $02, $02, $04, $02, $02, $02
  .byte $02, $02, $02, $02, $02, $02, $02, $02
  .byte $04, $04, $04, $00

nNull =*
  .byte $05, $00

